.. _ext-mixers:

****************
Mixer extensions
****************

Here you can find a list of external packages that extend Mopidy with
additional audio mixers by implementing the :ref:`mixer-api` which was added
in Mopidy 0.19.

This list is moderated and updated on a regular basis. If you want your package
to show up here, follow the :ref:`guide on creating extensions <extensiondev>`.


Mopidy-ALSAMixer
================

https://github.com/mopidy/mopidy-alsamixer

Extension for controlling volume one a Linux system using ALSA.


Mopidy-Arcam
============

https://github.com/TooDizzy/mopidy-arcam

Extension for controlling volume using an external Arcam amplifier. Developed
and tested with an Arcam AVR-300.


Mopidy-NAD
==========

https://github.com/mopidy/mopidy-nad

Extension for controlling volume using an external NAD amplifier. Developed
and tested with a NAD C355BEE.


Mopidy-SoftwareMixer
====================

Bundled with Mopidy. See :ref:`ext-softwaremixer`.


Mopidy-Yamaha
=============

https://github.com/knutz3n/mopidy-yamaha

Extension for controlling volume using an external Yamaha network connected
amplifier.
